* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Examples: Automations with Scripts](https://help.sap.com/docs/leanix/ea/examples-automations-with-scripts)
  * Updating Lifecycle Phases
